==> haskell-numbers-3000.2.0.2-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 numbers
version:              3000.2.0.2
visibility:           public
id:                   numbers-3000.2.0.2-Bk54pyaZXXH4gTOqHmeYYF
key:                  numbers-3000.2.0.2-Bk54pyaZXXH4gTOqHmeYYF
license:              BSD-3-Clause
maintainer:           johnw@newartisans.com
author:               Lennart Augustsson
homepage:             https://github.com/jwiegley/numbers#readme
synopsis:             Various number types
description:
    Instances of the numerical classes for a variety of
    different numbers: (computable) real numbers,
    arbitrary precision fixed numbers,
    arbitrary precision floating point numbers,
    differentiable numbers, symbolic numbers,
    natural numbers, interval arithmetic.

category:             Data, Math
abi:                  adbee37e1dc6dc5ec65b86fecaa6c39c
exposed:              True
exposed-modules:
    Data.Number.BigFloat Data.Number.CReal Data.Number.Dif
    Data.Number.Fixed Data.Number.FixedFunctions Data.Number.Interval
    Data.Number.Natural Data.Number.Symbolic Data.Number.Vectorspace

import-dirs:          /usr/lib/ghc-9.4.8/site-local/numbers-3000.2.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/numbers-3000.2.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/numbers-3000.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numbers
hs-libraries:         HSnumbers-3000.2.0.2-Bk54pyaZXXH4gTOqHmeYYF
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-numbers/html/numbers.haddock
haddock-html:         /usr/share/doc/haskell-numbers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-numbers-3000.2.0.2-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 numbers
version:              3000.2.0.2
visibility:           public
id:                   numbers-3000.2.0.2-1iE2OmdXNvYDDyaTmwUXE3
key:                  numbers-3000.2.0.2-1iE2OmdXNvYDDyaTmwUXE3
license:              BSD-3-Clause
maintainer:           johnw@newartisans.com
author:               Lennart Augustsson
homepage:             https://github.com/jwiegley/numbers#readme
synopsis:             Various number types
description:
    Instances of the numerical classes for a variety of
    different numbers: (computable) real numbers,
    arbitrary precision fixed numbers,
    arbitrary precision floating point numbers,
    differentiable numbers, symbolic numbers,
    natural numbers, interval arithmetic.

category:             Data, Math
abi:                  8b1e42f0612df65cde0933bbd04cc314
exposed:              True
exposed-modules:
    Data.Number.BigFloat Data.Number.CReal Data.Number.Dif
    Data.Number.Fixed Data.Number.FixedFunctions Data.Number.Interval
    Data.Number.Natural Data.Number.Symbolic Data.Number.Vectorspace

import-dirs:          /usr/lib/ghc-9.4.8/site-local/numbers-3000.2.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/numbers-3000.2.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/numbers-3000.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numbers
hs-libraries:         HSnumbers-3000.2.0.2-1iE2OmdXNvYDDyaTmwUXE3
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-numbers/html/numbers.haddock
haddock-html:         /usr/share/doc/haskell-numbers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
